@@ -1,4 +1,3 @@
-import time
 import datetime
 import zcc_utils.math_utils as math_utils
 
@@ -31,6 +30,15 @@ def float_hour_to_time(hour: float):
     second = math_utils.get_after_point_number_to_float(minute) * 60
     return datetime.time(hour=int(hour), minute=int(minute), second=int(second))
 
+def standard_time_format(time:str)->str:
+    """
+    将字符串时间转换为标准格式，例如 2019-1-3 15:29:08-> 2019-01-03 15:29:08
+    :param time: 非标准格式的时间字符串
+    :return: 标准格式的时间字符串
+    """
+    return str(datetime.datetime.strptime(time, '%Y-%m-%d %H:%M:%S'))
+
+
 
 if __name__ == "__main__":
     # time_local = time.localtime(1620557507)
